import requests
import json

def fundamentals(token): 
    url = "https://spawnerapi.com/fundamentals/" + token
    response = requests.get(url)
    return response.json()

def sharpe(token, ticker, time_purchased):
    url = "https://spawnerapi.com/sharpe/" + ticker + "/" + time_purchased + "/" + token
    response = requests.get(url)
    return response.text

def kelly_criterion(token, ticker):
    url = "https://spawnerapi.com/kelly-criterion/" + ticker + "/" + token
    response = requests.get(url)
    return response.text

def limit_order(token, identifier, key, ticker, quantity, side, limit_price):
    url = "https://spawnerapi.com/limit/" + identifier + "/" + key + "/" + ticker + "/" + quantity + "/" + side + "/"  + limit_price + "/" + token
    response = requests.get(url)
    return response.text



from setuptools import setup, find_packages  # noqa: H301

NAME = "spawner"
VERSION = "0.1.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["requests"]

setup(
    author="Spawner Team",
    author_email="info@spawner.ai",
    name=NAME,
    version=VERSION,
    description="Spawner API",
    url="https://github.com/spawner/python-sdk",
    keywords=["Spawner", "Python", "API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Welcome to the Spawner API! 
    """,
    
    classifiers=[
    'Development Status :: 3 - Alpha',   
    'Intended Audience :: Developers',     
    ],
)